==> qtjambi-multimedia-debuginfo-macos-6.6.0.jar: sources/QtJambiMultimedia/QCapturableWindow_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtMultimedia/qcapturablewindow.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiMultimedia/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCapturableWindow(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCapturableWindow")
    QCapturableWindow *_ptr = reinterpret_cast<QCapturableWindow *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QCapturableWindow()
void __qt_construct_QCapturableWindow_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCapturableWindow()")
    Q_UNUSED(__java_arguments)
    QCapturableWindow *__qt_this = new(__qtjambi_ptr) QCapturableWindow();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// new QCapturableWindow(QCapturableWindow)
void __qt_construct_QCapturableWindow_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCapturableWindow(QCapturableWindow)")
    jobject other0 = __java_arguments[0].l;
    const QCapturableWindow& __qt_other0 = qtjambi_cast<const QCapturableWindow& >(__jni_env, other0);
    QCapturableWindow *__qt_this = new(__qtjambi_ptr) QCapturableWindow(__qt_other0);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QCapturableWindow
void __qt_destruct_QCapturableWindow(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCapturableWindow")
    reinterpret_cast<QCapturableWindow*>(ptr)->~QCapturableWindow();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCapturableWindow::QCapturableWindow()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_initialize_1native__Lio_qt_multimedia_QCapturableWindow_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCapturableWindow::QCapturableWindow()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCapturableWindow_0, sizeof(QCapturableWindow), typeid(QCapturableWindow), false, &deleter_QCapturableWindow, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCapturableWindow::QCapturableWindow(QCapturableWindow)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_initialize_1native__Lio_qt_multimedia_QCapturableWindow_2Lio_qt_multimedia_QCapturableWindow_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCapturableWindow::QCapturableWindow(QCapturableWindow)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCapturableWindow_1, sizeof(QCapturableWindow), typeid(QCapturableWindow), false, &deleter_QCapturableWindow, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCapturableWindow::description()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_description_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCapturableWindow::description()const", __qt_this)
        QString __qt_return_value = __qt_this->description();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCapturableWindow::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCapturableWindow::isValid()const", __qt_this)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCapturableWindow::operator!=(QCapturableWindow,QCapturableWindow)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_operator_1not_1equal_1native_1cref_1QCapturableWindow__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCapturableWindow::operator!=(QCapturableWindow,QCapturableWindow)", __qt_this)
        const QCapturableWindow& __qt_rhs1 = QtJambiAPI::objectReferenceFromNativeId<QCapturableWindow>(__jni_env, rhs1);
        __java_return_value = (*__qt_this) != __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCapturableWindow::operator=(QCapturableWindow)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_assign_1native_1cref_1QCapturableWindow__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCapturableWindow::operator=(QCapturableWindow)", __qt_this)
        const QCapturableWindow& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCapturableWindow>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCapturableWindow::swap(QCapturableWindow&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_swap_1native_1ref_1QCapturableWindow__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCapturableWindow::swap(QCapturableWindow&)", __qt_this)
        QCapturableWindow& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCapturableWindow>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCapturableWindow(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCapturableWindow>("QCapturableWindow", "io/qt/multimedia/QCapturableWindow");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QCapturableWindow, {
        ConstructorInfo(&__qt_construct_QCapturableWindow_0, nullptr)
       ,ConstructorInfo(&__qt_construct_QCapturableWindow_1, "Lio/qt/multimedia/QCapturableWindow;")
    });
// END: function table

    registerMetaObject(typeId, QCapturableWindow::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCapturableWindow);
    registerMetaType<QCapturableWindow>("QCapturableWindow");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-multimedia-debuginfo-macos-6.7.1.jar: sources/QtJambiMultimedia/QCapturableWindow_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtMultimedia/qcapturablewindow.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiMultimedia/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QCapturableWindow(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QCapturableWindow")
    QCapturableWindow *_ptr = reinterpret_cast<QCapturableWindow *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new QCapturableWindow()
void __qt_construct_QCapturableWindow(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCapturableWindow()")
    Q_UNUSED(__java_arguments)
    QCapturableWindow *__qt_this = new(__qtjambi_ptr) QCapturableWindow();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QCapturableWindow::QCapturableWindow()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_initialize_1native__Lio_qt_multimedia_QCapturableWindow_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCapturableWindow::QCapturableWindow()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCapturableWindow, sizeof(QCapturableWindow), typeid(QCapturableWindow), 0, false, &deleter_QCapturableWindow, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QCapturableWindow(QCapturableWindow)
void __qt_construct_QCapturableWindow_cref_QCapturableWindow(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QCapturableWindow(QCapturableWindow)")
    jobject other0 = __java_arguments[0].l;
    const QCapturableWindow& __qt_other0 = qtjambi_cast<const QCapturableWindow&>(__jni_env, other0);
    QCapturableWindow *__qt_this = new(__qtjambi_ptr) QCapturableWindow(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QCapturableWindow::QCapturableWindow(QCapturableWindow)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_initialize_1native__Lio_qt_multimedia_QCapturableWindow_2Lio_qt_multimedia_QCapturableWindow_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QCapturableWindow::QCapturableWindow(QCapturableWindow)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QCapturableWindow_cref_QCapturableWindow, sizeof(QCapturableWindow), typeid(QCapturableWindow), 0, false, &deleter_QCapturableWindow, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QCapturableWindow
void __qt_destruct_QCapturableWindow(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QCapturableWindow")
    reinterpret_cast<QCapturableWindow*>(ptr)->~QCapturableWindow();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QCapturableWindow::description()const
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_description_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        const QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCapturableWindow::description()const", __this_nativeId)
        QString __qt_return_value = __qt_this->description();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCapturableWindow::isValid()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_isValid_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCapturableWindow::isValid()const", __this_nativeId)
        __java_return_value = __qt_this->isValid();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCapturableWindow::operator=(QCapturableWindow)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_assign_1native_1cref_1QCapturableWindow__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCapturableWindow::operator=(QCapturableWindow)", __this_nativeId)
        const QCapturableWindow& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCapturableWindow>(__jni_env, other0);
        (*__qt_this) = __qt_other0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QCapturableWindow::operator==(QCapturableWindow,QCapturableWindow)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_equals_1native_1cref_1QCapturableWindow__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID rhs1)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCapturableWindow::operator==(QCapturableWindow,QCapturableWindow)", __this_nativeId)
        const QCapturableWindow& __qt_rhs1 = QtJambiAPI::objectReferenceFromNativeId<QCapturableWindow>(__jni_env, rhs1);
        __java_return_value = (*__qt_this) == __qt_rhs1;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QCapturableWindow::swap(QCapturableWindow&)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_swap_1native_1ref_1QCapturableWindow__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID other0)
{
    Q_UNUSED(__this)
    QTJAMBI_TRY {
        QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QCapturableWindow::swap(QCapturableWindow&)", __this_nativeId)
        QCapturableWindow& __qt_other0 = QtJambiAPI::objectReferenceFromNativeId<QCapturableWindow>(__jni_env, other0);
        __qt_this->swap(__qt_other0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

#include <QtCore/QDebug>
extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_toString_1native)(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value = nullptr;
    QTJAMBI_TRY {
        QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString res;
        QDebug(&res).noquote() << *__qt_this;
        if(!res.isEmpty() && res.back().isSpace())
            res = res.trimmed();
        __java_return_value = qtjambi_cast<jstring>(__jni_env, res);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_multimedia_QCapturableWindow_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QCapturableWindow *__qt_this = QtJambiAPI::objectFromNativeId<QCapturableWindow>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QCapturableWindow(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QCapturableWindow>("QCapturableWindow", "io/qt/multimedia/QCapturableWindow");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QCapturableWindow, {
        ConstructorInfo(&__qt_construct_QCapturableWindow, nullptr)
       ,ConstructorInfo(&__qt_construct_QCapturableWindow_cref_QCapturableWindow, "Lio/qt/multimedia/QCapturableWindow;")
    });
// END: function table

    registerMetaObject(typeId, QCapturableWindow::staticMetaObject, false);
// END: signal table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QCapturableWindow);
    registerMetaType<QCapturableWindow>("QCapturableWindow");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
